<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Rubenz_Widget_Slider_Images extends Rubenz_Widget_Base {
	protected static $_instance = null;

	public function get_name() {
		return 'rubenz-widget-slider-images';
	}

	public function get_title() {
		return esc_html__( 'Slider Images', 'rubenz' );
	}

	public function get_icon() {
		return 'eicon-plug';
	}

	public function get_categories() {
		return array( 'rubenz-static' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Images', 'rubenz' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'images_gallery',
			array(
				'type'    => Controls_Manager::GALLERY,
				'default' => array(),
			)
		);

		$this->add_control(
			'enable_captions',
			array(
				'label'   => esc_html__( 'Enable Image Captions', 'rubenz' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'captions_position',
			array(
				'label'     => esc_html__( 'Captions Position', 'rubenz' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => array(
					'slider__caption_top'    => array(
						'title' => esc_html__( 'Top', 'rubenz' ),
						'icon'  => 'eicon-v-align-top',
					),
					'slider__caption_bottom' => array(
						'title' => esc_html__( 'Bottom', 'rubenz' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'default'   => 'slider__caption_top',
				'toggle'    => false,
				'condition' => array(
					'enable_captions' => 'yes',
				),
			)
		);

		$this->end_controls_section();

		/**
		 * Section Slider
		 */
		$this->start_controls_section(
			'slider_section',
			array(
				'label' => esc_html__( 'Slider', 'rubenz' ),
				'tab'   => Controls_Manager::TAB_SETTINGS,
			)
		);

		$this->add_responsive_control(
			'slides_per_view',
			array(
				'label'              => esc_html__( 'Slides Per Screen', 'rubenz' ),
				'type'               => Controls_Manager::SLIDER,
				'range'              => array(
					'number' => array(
						'min'  => 1,
						'max'  => 5,
						'step' => 0.1,
					),
				),
				'devices'            => array( 'desktop', 'tablet', 'mobile' ),
				'default'            => array(
					'size' => 3.5,
					'unit' => 'number',
				),
				'desktop_default'    => array(
					'size' => 3.5,
					'unit' => 'number',
				),
				'tablet_default'     => array(
					'size' => 1.33,
					'unit' => 'number',
				),
				'mobile_default'     => array(
					'size' => 1.33,
					'unit' => 'number',
				),
				'render_type'        => 'template',
				'frontend_available' => true,
			)
		);

		$this->add_responsive_control(
			'centered_slides',
			array(
				'label'              => esc_html__( 'Horizontally Centered Slides', 'rubenz' ),
				'label_block'        => true,
				'type'               => Controls_Manager::SWITCHER,
				'default'            => 'yes',
				'desktop_default'    => 'yes',
				'tablet_default'     => 'yes',
				'mobile_default'     => 'yes',
				'render_type'        => 'template',
				'frontend_available' => true,
			)
		);

		$this->add_control(
			'vertical_centered_slides',
			array(
				'label'   => esc_html__( 'Vertically Centered Slides', 'rubenz' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_responsive_control(
			'space_between',
			array(
				'label'              => esc_html__( 'Space Between Slides', 'rubenz' ),
				'type'               => Controls_Manager::SLIDER,
				'range'              => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
				),
				'devices'            => array( 'desktop', 'tablet', 'mobile' ),
				'default'            => array(
					'size' => 30,
					'unit' => 'px',
				),
				'desktop_default'    => array(
					'size' => 30,
					'unit' => 'px',
				),
				'tablet_default'     => array(
					'size' => 15,
					'unit' => 'px',
				),
				'mobile_default'     => array(
					'size' => 15,
					'unit' => 'px',
				),
				'render_type'        => 'template',
				'frontend_available' => true,
			)
		);

		$this->add_control(
			'enable_progress',
			array(
				'label'   => esc_html__( 'Enable Progress Bar', 'rubenz' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'enable_autoplay',
			array(
				'label'   => esc_html__( 'Autoplay', 'rubenz' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			)
		);

		$this->add_control(
			'autoplay_delay',
			array(
				'label'     => esc_html__( 'Autoplay Delay (ms)', 'rubenz' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => array(
					'ms' => array(
						'min'  => 1000,
						'max'  => 60000,
						'step' => 100,
					),
				),
				'default'   => array(
					'unit' => 'ms',
					'size' => 6000,
				),
				'condition' => array(
					'enable_autoplay' => 'yes',
				),
			)
		);

		$this->add_control(
			'speed',
			array(
				'label'   => esc_html__( 'Speed', 'rubenz' ),
				'type'    => Controls_Manager::SLIDER,
				'range'   => array(
					'ms' => array(
						'min'  => 100,
						'max'  => 10000,
						'step' => 100,
					),
				),
				'default' => array(
					'unit' => 'ms',
					'size' => 1200,
				),
			)
		);

		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Direction', 'rubenz' ),
				'type'    => Controls_Manager::CHOOSE,
				'default' => 'ltr',
				'options' => array(
					'ltr' => array(
						'title' => esc_html__( 'Left to Right', 'rubenz' ),
						'icon'  => 'eicon-chevron-double-right',
					),
					'rtl' => array(
						'title' => esc_html__( 'Right to Left', 'rubenz' ),
						'icon'  => 'eicon-chevron-double-left',
					),
				),
				'toggle'  => false,
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute(
			'swiper',
			array(
				'class'                       => array( 'swiper', 'swiper-container', 'slider', 'slider_draggable', 'slider-images', 'js-slider-images', 'text-center' ),
				'data-speed'                  => $settings['speed']['size'],
				'dir'                         => $settings['direction'],
				'data-slides-per-view'        => $settings['slides_per_view']['size'],
				'data-space-between'          => $settings['space_between']['size'],
				'data-centered-slides'        => $settings['centered_slides'],
				'data-auto-height'            => 'true',
			)
		);

		if ( array_key_exists( 'slides_per_view_tablet', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-slides-per-view-tablet', $settings['slides_per_view_tablet']['size'] );
		}

		if ( array_key_exists( 'slides_per_view_mobile', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-slides-per-view-mobile', $settings['slides_per_view_mobile']['size'] );
		}

		if ( array_key_exists( 'space_between_tablet', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-space-between-tablet', $settings['space_between_tablet']['size'] );
		}

		if ( array_key_exists( 'space_between_mobile', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-space-between-mobile', $settings['space_between_mobile']['size'] );
		}

		if ( array_key_exists( 'centered_slides_tablet', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-centered-slides-tablet', $settings['centered_slides_tablet'] ? 'true' : 'false' );
		}

		if ( array_key_exists( 'centered_slides_mobile', $settings ) ) {
			$this->add_render_attribute( 'swiper', 'data-centered-slides-mobile', $settings['centered_slides_mobile'] ? 'true' : 'false' );
		}

		if ( $settings['enable_autoplay'] ) {
			$this->add_render_attribute(
				'swiper',
				array(
					'data-autoplay-enabled' => 'true',
					'data-autoplay-delay'   => $settings['autoplay_delay']['size'],
				)
			);
		}

		if ( $settings['vertical_centered_slides'] ) {
			$this->add_render_attribute(
				'swiper',
				array(
					'class' => 'slider_vertical-centered',
				)
			);
		}
		?>
		<div <?php echo $this->get_render_attribute_string( 'swiper' ); ?>>
			<div class="swiper-wrapper">
				<?php if ( ! empty( $settings['images_gallery'] ) ) : ?>
					<?php foreach ( $settings['images_gallery'] as $image ) : ?>
						<div class="swiper-slide slider__slide">
							<?php $title = get_the_title( $image['id'] ); ?>
							<?php if ( $settings['enable_captions'] && ! empty( $title ) && $settings['captions_position'] == 'slider__caption_top' ) : ?>
								<div class="slider__caption <?php echo $settings['captions_position']; ?>"><?php echo $title; ?></div>
							<?php endif; ?>
								<?php
									arts_the_lazy_image(
										array(
											'id'    => $image['id'],
											'type'  => 'image',
											'class' => array(
												'wrapper' => array( 'lazy_swiper' ),
												'image'   => array( 'swiper-lazy' ),
											),
										)
									);
								?>
							<?php if ( $settings['enable_captions'] && ! empty( $title ) && $settings['captions_position'] == 'slider__caption_bottom' ) : ?>
								<div class="slider__caption <?php echo $settings['captions_position']; ?>"><?php echo $title; ?></div>
							<?php endif; ?>
						</div>
					<?php endforeach; ?>
				<?php endif; ?>
			</div>
			<?php if ( $settings['enable_progress'] ) : ?>
				<div class="slider__progress">
					<div class="swiper swiper-container slider__counter slider__counter_current js-slider-images-counter-current">
						<div class="swiper-wrapper"></div>
					</div>
					<div class="slider__progressbar js-slider-images-progress">
						<div class="slider__progressbar-fill"></div>
					</div>
					<div class="slider__counter slider__counter_total js-slider-images-counter-total">00</div>
				</div>
				<!-- - slider progress -->
			<?php endif; ?>
		</div>
		<?php
	}
}
