<?php
/**
 * Plugin Name: Rubenz Core
 * Description: Core Plugin for Rubenz WordPress Theme
 * Plugin URI: https://artemsemkin.com/
 * Version: 3.1.1
 * Requires at least: 6.4
 * Requires PHP: 7.0
 * Author: Artem Semkin
 * Update URI: artemsemkin.com
 * Tested up to: 6
 * Text Domain: rubenz
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'ARTS_RUBENZ_CORE_PLUGIN_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'ARTS_RUBENZ_CORE_PLUGIN_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
define( 'ARTS_RUBENZ_CORE_PLUGIN_VERSION', get_file_data( __FILE__, array( 'ver' => 'Version' ), false )['ver'] );

require_once __DIR__ . '/elementor/rubenz_elementor_extension.php';
require_once __DIR__ . '/elementor/document_settings.php';
require_once __DIR__ . '/inc/add_custom_mime_types.php';
require_once __DIR__ . '/inc/cpt.php';
require_once __DIR__ . '/inc/helper_functions.php';
require_once __DIR__ . '/inc/get_gmap_key.php';
require_once __DIR__ . '/inc/shortcodes.php';
require_once __DIR__ . '/inc/taxonomies.php';
require_once __DIR__ . '/inc/widgets.php';

/**
 * Plugin Updates API
 */
if ( ! class_exists( 'Rubenz_Core_Plugin_Update' ) ) {
	require_once __DIR__ . '/inc/update.php';
}
$config_core_plugin_update = array(
	'theme_id'  => 'rubenz',
	'plugin_id' => plugin_basename( __FILE__ ),
	'endpoint'  => esc_url( 'https://artemsemkin.com/wp-json/edd/v1/update/rubenz/core-plugin' ),
	'icons'     => array(
		'svg' => esc_url( trailingslashit( ARTS_RUBENZ_CORE_PLUGIN_URL ) . 'assets/icon.svg' ),
		'1x'  => esc_url( trailingslashit( ARTS_RUBENZ_CORE_PLUGIN_URL ) . 'assets/icon-128x128.jpg' ),
		'2x'  => esc_url( trailingslashit( ARTS_RUBENZ_CORE_PLUGIN_URL ) . 'assets/icon-256x256.jpg' ),
	),
	'banners'   => array(
		'low'  => esc_url( trailingslashit( ARTS_RUBENZ_CORE_PLUGIN_URL ) . 'assets/banner-772x250.jpg' ),
		'high' => esc_url( trailingslashit( ARTS_RUBENZ_CORE_PLUGIN_URL ) . 'assets/banner-1544x500.jpg' ),
	),
);
new Rubenz_Core_Plugin_Update( $config_core_plugin_update );

/**
 * Bundled Plugins Updates API
 */
if ( ! class_exists( 'Arts_Bundled_Plugins_Update' ) ) {
	require_once __DIR__ . '/inc/update_bundled_plugin.php';
}
$config_acf_pro_update = array(
	'theme_id'  => 'rubenz',
	'plugin_id' => 'advanced-custom-fields-pro/acf.php',
	'endpoint'  => esc_url( 'https://artemsemkin.com/wp-json/edd/v1/update/acf-pro/plugin' ),
);
new Arts_Bundled_Plugins_Update( $config_acf_pro_update );

add_action( 'init', 'arts_load_textdomain' );
function arts_load_textdomain() {
	load_plugin_textdomain( 'rubenz' );
}
